@@ -23,7 +23,7 @@
 
 package Math::Roman;
 use vars qw($VERSION);
-$VERSION = 1.07;	# Current version of this package
+$VERSION = 1.08;	# Current version of this package
 require  5.005;		# requires this Perl version or later
 
 require Exporter;
@@ -56,7 +56,7 @@ sub roman
   # if first failed, so check for Roman
   _initialize($self,$value) if $self->{sign} eq 'NaN';
   bless $self, $c;						# rebless
-  $self; 
+  $self;
   }
 
 sub error
@@ -75,7 +75,7 @@ sub new
   # if first failed, so check for Roman
   _initialize($self,$value) if $self->{sign} eq 'NaN';
   bless $self, $c;						# rebless
-  $self; 
+  $self;
   }
 
 #############################################################################
@@ -92,7 +92,7 @@ sub tokens
   my $sl = []; # a list sorted by name-length
   $ss = [];
   $sh = {}; $sm = {};
-  $bv = -1; $bt = ''; $re = ""; 
+  $bv = -1; $bt = ''; $re = "";
   my $i;
   for ($i = 0; $i<@sym;$i += 2)
     {
@@ -101,7 +101,7 @@ sub tokens
     $sh->{$sym[$i]} = int($sym[$i+1]); # contain all token=>value
     if (int($sym[$i+1]) != -1)         # only valid ones
       {
-      push @$ss,int($sym[$i+1]);       # for regexp compiler 
+      push @$ss,int($sym[$i+1]);       # for regexp compiler
       $sm->{$sym[$i+1]} = $sym[$i];    # generate hash for value=>token
       ($bt,$bv) = ($sym[$i],int($sym[$i+1])) if (int($sym[$i+1]) > $bv);
       }
@@ -119,7 +119,7 @@ sub tokens
 
 BEGIN
   {
-  tokens( qw( 
+  tokens( qw(
 	IIII		-1
 	XXXX		-1
 	CCCC		-1
@@ -150,16 +150,16 @@ BEGIN
 	D	500
 	M	1000
   ) );
-  undef $err; 
+  undef $err;
   }
-  
+
   # check for illegal sequences (simple return, we are already NaN)
-  # the following are not valid tokens according to rules: 
+  # the following are not valid tokens according to rules:
   # IIII
   # XXXX
   # CCCC
   # only ICX as precede:
-  # VX  5	
+  # VX  5
   # VL  45
   # VC  95
   # VD  495
@@ -176,16 +176,16 @@ BEGIN
   # XM  990
   # illegal ones, smaller then following (several cases are already caught
   # by rule: token0 < token1)
-  # CDD (C < D) 
-  # CDC (C = C) 
+  # CDD (C < D)
+  # CDC (C = C)
   # XCD (X < D)
   # LXL (L = L)
   # They need to be checked separetely, the following regexps take care
   # of that:
   # C[MD][CDM]
   # X[LC][XLCDM]
-  # I[VX][IVXLCDM] 
-  
+  # I[VX][IVXLCDM]
+
 sub _initialize
   {
   # set yourself to the value represented by the given string
@@ -206,7 +206,7 @@ sub _initialize
       }
     else
       {
-      $err = "Math::Roman: Invalid part '$value' encountered."; 
+      $err = "Math::Roman: Invalid part '$value' encountered.";
       $e = 4;
       }
     }
@@ -223,21 +223,21 @@ sub _symb
   #print "$k" if defined $k;
   if (!defined $k)
     {
-    $err = "Math::Roman: Undefined token '$s' encountered."; 
+    $err = "Math::Roman: Undefined token '$s' encountered.";
     $$error = 1;
     }
   else
     {
     if ($k == -1)
       {
-      $err = "Math::Roman: Invalid token '$s' encountered."; 
+      $err = "Math::Roman: Invalid token '$s' encountered.";
       $$error = 2;
       }
     $$last = $k if $$last == -1;
     # next symbol must always be smaller then previous
     if ($k > $$last)
       {
-      $err = "Math::Roman: Token '$s' ($k) is greater than last ('$$last')."; 
+      $err = "Math::Roman: Token '$s' ($k) is greater than last ('$$last').";
       $$error = 3;
       }
     }
@@ -273,7 +273,7 @@ sub bstr
       return 'NaN';
       }
     # this limits $cnt to be < 65536, anyway 65536 Ms is impressive though)
-    $cnt = int ($cnt); 
+    $cnt = int ($cnt);
     $es .= $sm->{$ss->[$level]} x $cnt if $cnt != 0;
     }
   return $es;
@@ -283,19 +283,19 @@ sub bstr
   #if ($rem > $bv)
   #  {
   #  # calculate number of biggest token
-  #  ($cnt,$rem) = $rem->bdiv($bv); 
+  #  ($cnt,$rem) = $rem->bdiv($bv);
   #  if ($rem->sign() eq 'NaN')
   #    {
   #    warn ("Something went wrong with bt='$bt' and bv='$bv'");
   ##    return 'NaN';
   #    }
   #  # this limits $cnt to be < 65536, anyway 65536 Ms is impressive though)
-  #  $es = $bt x $cnt; 
+  #  $es = $bt x $cnt;
   #  }
   #return $es if $rem->is_zero();
   # find combination of tokens (with decreasing value) that matches reminder
   # restricted knappsack problem with symbols in @sym, sum 1...999
-  #my $stack = []; my $value = 0; 
+  #my $stack = []; my $value = 0;
   #_recurse(0,\$value,$stack,int($rem));
   #print "done $value $rem\n";
   # found valid combination? (should never fail if system is consistent!)
@@ -303,7 +303,7 @@ sub bstr
   #  {
   #  map { $es .= $_ } @$stack;
   #  # {
-  #  # $es .= $_; 
+  #  # $es .= $_;
   ##  # }
   #  # $es .= join //,@$stack; # faster but gives error!?
   #  return $es;
@@ -343,10 +343,13 @@ sub as_number
   }
 
 1;
+
 __END__
 
 #############################################################################
 
+=pod
+
 =head1 NAME
 
 Math::Roman - Arbitrary sized Roman numbers and conversion from and to Arabic.
@@ -358,9 +361,9 @@ Math::Roman - Arbitrary sized Roman numbers and conversion from and to Arabic.
     $a = new Math::Roman 'MCMLXXIII';  # 1973
     $b = roman('MCMLXI');              # 1961
     print $a - $b,"\n";                # prints 'XII'
-   
+
     $d = Math::Roman->bzero();         # ''
-    $d++;                              # 'I'  
+    $d++;                              # 'I'
     $d += 1998;                        # 'MCMXCIX'
     $d -= 'MCM';                       # 'XCIX'
 
@@ -373,7 +376,7 @@ perl5.005, Exporter, Math::BigInt
 
 =head1 EXPORTS
 
-Exports nothing on default, but can export C<as_number()>, C<roman()>, 
+Exports nothing on default, but can export C<as_number()>, C<roman()>,
 and C<error()>.
 
 =head1 DESCRIPTION
@@ -384,7 +387,7 @@ This module lets you calculate with Roman numbers, as if they were big
 integers. The numbers can have arbitrary length and all the usual functions
 from Math::BigInt are available.
 
-=head2 INPUT
+=head2 Input
 
 The Roman single digits are as follows:
 
@@ -398,9 +401,9 @@ The Roman single digits are as follows:
 
 The following (quite modern) rules are in effect:
 
-=over 1
+=over
 
-Each of I, X and C can be repeated up to 3 times, V, L and D only once. 
+Each of I, X and C can be repeated up to 3 times, V, L and D only once.
 Technically, M could be used up to four times, but this module imposes
 no limit on this to allow arbitrarily big numbers.
 
@@ -409,17 +412,17 @@ IVXLCDM or consist of two digits, whereas the first digit is smaller than
 the second one. In the latter case the first digit is subtracted from the
 second (e.g. IV means 4, not 6).
 
-The smaller number must be a power of ten (I, X or C) and precede a 
-number no larger than 10 times its own value. The smaller number itself 
-can be preceded only by a number at least 10 times greater (e.g. LXC is 
+The smaller number must be a power of ten (I, X or C) and precede a
+number no larger than 10 times its own value. The smaller number itself
+can be preceded only by a number at least 10 times greater (e.g. LXC is
 invalid) and it must also be larger than any numeral that follows the one
 from which it is being subtracted (e.g. CMD is invalid).
 
 Each token must be smaller than the token before (e.g. IIV is invalid,
 since I is smaller than IV).
 
-The input will be checked and the result will be a 'NaN' if the check 
-fails. You can get the cause with C<Math::Roman::error()> until you try 
+The input will be checked and the result will be a 'NaN' if the check
+fails. You can get the cause with C<Math::Roman::error()> until you try
 to create the next Roman number.
 
 The default list of valid tokens a Roman number can consist of is thus:
@@ -447,35 +450,35 @@ The default list of valid tokens a Roman number can consist of is thus:
 The default list of invalid tokens is as follows:
 
 	IIII		XXXX		CCCC
-	DD		LL		VV		
-	C[MD][CDM]	X[LC][XLCDM]    I[VX][IVXLCDM]  
+	DD		LL		VV
+	C[MD][CDM]	X[LC][XLCDM]    I[VX][IVXLCDM]
 
 =back
 
-Thanx must go to http://netdirect.net/~charta/Roman_numerals.html for 
+Thanx must go to http://netdirect.net/~charta/Roman_numerals.html for
 clarifications.
 
-=head2 OUTPUT
+=head2 Output
 
 The output will always be of the shortest possible form, and the tokens
 will be arranged in a decreasing order.
 
 =head1 BENDING THE RULES
 
-You can use C<Math::Roman::tokens()> to get an array with all the defined 
-tokens and their value. Tokens with a value of -1 are invalid, all others 
+You can use C<Math::Roman::tokens()> to get an array with all the defined
+tokens and their value. Tokens with a value of -1 are invalid, all others
 are valid. The format is token0, value0, token1, value1...
 
 You can create your own set and store it with C<Math::Roman::tokens()>.
-The routine expects an array of the form token, value, token, value... 
+The routine expects an array of the form token, value, token, value...
 etc.  Each token can be a simple string or regular expresion. Values of
 -1 indicate invalid tokens.
 
-Here is an example that removes the subtraction (only addition is valid) 
+Here is an example that removes the subtraction (only addition is valid)
 as well as most of the other rules. It then parses 'XIIII' to be 14, then
 redefine the token set completely and parses 'AAB' to be 25:
 
-=over 1
+=over
 
 	use Math::Roman;
 
@@ -495,63 +498,67 @@ multiplying by 1000. Since it is hard to do this in ASCII, lower-case
 letters could be used like in the following:
 
 	use Math::Roman;
-	
+
         # will wrongly ommit the 'M's, but so much 'M's would not fit
 	# on your screen anyway
 	print 'old: ',new Math::Roman ('+12345678901234567890'),"\n";
 	@a = Math::Roman::tokens();
-	push @a, qw ( v 5000  x 10000  l 50000  c 100000  d 500000  
+	push @a, qw ( v 5000  x 10000  l 50000  c 100000  d 500000
 		      m 1000000 );
 	Math::Roman::tokens(@a);
 	print 'new: ',new Math::Roman ('+12345678901234567890'),"\n";
 
-=head1 USEFULL METHODS
+=head1 USEFUL METHODS
 
-=head2 B<new()>
+=over
+
+=item new()
 
             new();
 
-Create a new Math::Roman object. Argument is a Roman number as string, 
+Create a new Math::Roman object. Argument is a Roman number as string,
 like 'MCMLXXIII' (1973) of the form /^[IVXLCDM]*$/ (see above for further
 rules) or a string number as used by Math::BigInt.
 
-=head2 B<roman()>
+=item roman()
 
             roman();
 
 Just like new, but you can import it to write shorter code.
 
-=head2 B<error()>
+=item error()
 
 	    Math::Roman::error();
 
 Return error of last number creation when result was NaN.
 
-=head2 B<bstr()>
+=item bstr()
 
             $roman->bstr();
 
-Return a string representing the internal value as a Roman number 
-according to the aforementioned rules. A zero will be represented by 
-''.  The output will only consist of valid tokens, and not contain a 
+Return a string representing the internal value as a Roman number
+according to the aforementioned rules. A zero will be represented by
+''.  The output will only consist of valid tokens, and not contain a
 sign.  Use C<as_number()> if you need the sign.
 
 This function always generates the shortest possible form.
 
-=head2 B<as_number()>
+=item as_number()
 
             $roman->as_number();
 
 Return a string representing the internal value as a normalized arabic
 number, including sign.
 
+=back
+
 =head1 DETAILS
 
 Uses internally Math::BigInt to do the math, all with overloaded
 operators.
 
-Roman has neither negative numbers nor zero, but this module handles 
-these, too. You will get only the absolute value as Roman number, but 
+Roman has neither negative numbers nor zero, but this module handles
+these, too. You will get only the absolute value as Roman number, but
 can look at the sign with C<sign()> or use C<as_number()>.
 
 =head1 EXAMPLES
@@ -568,37 +575,31 @@ can look at the sign with C<sign()> or use C<as_number()>.
   $a = roman('MCMLXXII');
   print "\$a is now $a (",$a->as_number(),")\n";
   $a++; $a += 'MCMXII'; $a = $a * 'X' - 'I';
-  print "\$a is now $a (",$a->as_number(),")\n"; 
+  print "\$a is now $a (",$a->as_number(),")\n";
 
 =head1 LIMITS
 
-=over 1
+=head2 Internal Number Length
 
-=item Internal Number Length
+For the actual math, the same limits as in Math::BigInt apply.
 
-For the actual math, the same limits as in Math::BigInt apply. 
-
-=item Output length
+=head2 Output length
 
 The output in Roman is limited to 65536 times the biggest symbol. With
 the default set this is 'M', so the biggest Roman number you can print
 is 65536000 - and it will give you 64 KBytes M's in a row. This could be
 fixed, but who really needs it? ;)
 
-=item Number Rules
+=head2 Number Rules
 
 The rule "Each token must be greater than the token before" is
 hard-coded in and can not be overcome. So 'IIX' will be invalid for
 subtraction-less numbers unless you define an 'IIX' token with a value
 of 12.
 
-=back
-
 =head1 BUGS
 
-=over 1
-
-=item Importing functions
+=head2 Importing functions
 
 You can not import ordinary math functions like C<badd()> and write
 things like:
@@ -617,12 +618,50 @@ I think this is really not needed, since you can always use:
 	$a = new Math::Roman 'MCM'; $a += 'M';	# neat isn't it?
 	$a = Math::Roman->badd('MCM','M');	# or this
 
-=item '0'-'9' as tokens
+=head2 '0'-'9' as tokens
 
 0-9 in the token set produce wrong results in new() if the given argument
 consists only of 0-9. That is because first a BigInt is tried to be
 constructed, and in this case, would succeed.
 
+=head2 Reporting bugs
+
+Please report any bugs or feature requests to
+C<bug-math-roman at rt.cpan.org>, or through the web interface at
+L<https://rt.cpan.org/Ticket/Create.html?Queue=Math-Roman> (requires login).
+We will be notified, and then you'll automatically be notified of progress on
+your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Math::Roman
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<https://rt.cpan.org/Dist/Display.html?Name=Math-Roman>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Math-Roman>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Math-Roman>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Math-Roman/>
+
+=item * CPAN Testers Matrix
+
+L<http://matrix.cpantesters.org/?dist=Math-Roman>
+
 =back
 
 =head1 LICENSE
